==> applicationautoscaling-1.60.0-sources.jar: software/amazon/awscdk/services/applicationautoscaling/ScalingSchedule.java <==
package software.amazon.awscdk.services.applicationautoscaling;

/**
 * A scheduled scaling action.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:06.036Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.applicationautoscaling.$Module.class, fqn = "@aws-cdk/aws-applicationautoscaling.ScalingSchedule")
@software.amazon.jsii.Jsii.Proxy(ScalingSchedule.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ScalingSchedule extends software.amazon.jsii.JsiiSerializable {

    /**
     * When to perform this action.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.Schedule getSchedule();

    /**
     * When this scheduled action expires.
     * <p>
     * Default: The rule never expires.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.time.Instant getEndTime() {
        return null;
    }

    /**
     * The new maximum capacity.
     * <p>
     * During the scheduled time, the current capacity is above the maximum
     * capacity, Application Auto Scaling scales in to the maximum capacity.
     * <p>
     * At least one of maxCapacity and minCapacity must be supplied.
     * <p>
     * Default: No new maximum capacity
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxCapacity() {
        return null;
    }

    /**
     * The new minimum capacity.
     * <p>
     * During the scheduled time, if the current capacity is below the minimum
     * capacity, Application Auto Scaling scales out to the minimum capacity.
     * <p>
     * At least one of maxCapacity and minCapacity must be supplied.
     * <p>
     * Default: No new minimum capacity
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMinCapacity() {
        return null;
    }

    /**
     * When this scheduled action becomes active.
     * <p>
     * Default: The rule is activate immediately
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.time.Instant getStartTime() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ScalingSchedule> {
        private software.amazon.awscdk.services.applicationautoscaling.Schedule schedule;
        private java.time.Instant endTime;
        private java.lang.Number maxCapacity;
        private java.lang.Number minCapacity;
        private java.time.Instant startTime;

        /**
         * Sets the value of {@link ScalingSchedule#getSchedule}
         * @param schedule When to perform this action. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schedule(software.amazon.awscdk.services.applicationautoscaling.Schedule schedule) {
            this.schedule = schedule;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getEndTime}
         * @param endTime When this scheduled action expires.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder endTime(java.time.Instant endTime) {
            this.endTime = endTime;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getMaxCapacity}
         * @param maxCapacity The new maximum capacity.
         *                    During the scheduled time, the current capacity is above the maximum
         *                    capacity, Application Auto Scaling scales in to the maximum capacity.
         *                    <p>
         *                    At least one of maxCapacity and minCapacity must be supplied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxCapacity(java.lang.Number maxCapacity) {
            this.maxCapacity = maxCapacity;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getMinCapacity}
         * @param minCapacity The new minimum capacity.
         *                    During the scheduled time, if the current capacity is below the minimum
         *                    capacity, Application Auto Scaling scales out to the minimum capacity.
         *                    <p>
         *                    At least one of maxCapacity and minCapacity must be supplied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minCapacity(java.lang.Number minCapacity) {
            this.minCapacity = minCapacity;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getStartTime}
         * @param startTime When this scheduled action becomes active.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startTime(java.time.Instant startTime) {
            this.startTime = startTime;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ScalingSchedule}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ScalingSchedule build() {
            return new Jsii$Proxy(schedule, endTime, maxCapacity, minCapacity, startTime);
        }
    }

    /**
     * An implementation for {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ScalingSchedule {
        private final software.amazon.awscdk.services.applicationautoscaling.Schedule schedule;
        private final java.time.Instant endTime;
        private final java.lang.Number maxCapacity;
        private final java.lang.Number minCapacity;
        private final java.time.Instant startTime;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.schedule = this.jsiiGet("schedule", software.amazon.awscdk.services.applicationautoscaling.Schedule.class);
            this.endTime = this.jsiiGet("endTime", java.time.Instant.class);
            this.maxCapacity = this.jsiiGet("maxCapacity", java.lang.Number.class);
            this.minCapacity = this.jsiiGet("minCapacity", java.lang.Number.class);
            this.startTime = this.jsiiGet("startTime", java.time.Instant.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.applicationautoscaling.Schedule schedule, final java.time.Instant endTime, final java.lang.Number maxCapacity, final java.lang.Number minCapacity, final java.time.Instant startTime) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.schedule = java.util.Objects.requireNonNull(schedule, "schedule is required");
            this.endTime = endTime;
            this.maxCapacity = maxCapacity;
            this.minCapacity = minCapacity;
            this.startTime = startTime;
        }

        @Override
        public software.amazon.awscdk.services.applicationautoscaling.Schedule getSchedule() {
            return this.schedule;
        }

        @Override
        public java.time.Instant getEndTime() {
            return this.endTime;
        }

        @Override
        public java.lang.Number getMaxCapacity() {
            return this.maxCapacity;
        }

        @Override
        public java.lang.Number getMinCapacity() {
            return this.minCapacity;
        }

        @Override
        public java.time.Instant getStartTime() {
            return this.startTime;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("schedule", om.valueToTree(this.getSchedule()));
            if (this.getEndTime() != null) {
                data.set("endTime", om.valueToTree(this.getEndTime()));
            }
            if (this.getMaxCapacity() != null) {
                data.set("maxCapacity", om.valueToTree(this.getMaxCapacity()));
            }
            if (this.getMinCapacity() != null) {
                data.set("minCapacity", om.valueToTree(this.getMinCapacity()));
            }
            if (this.getStartTime() != null) {
                data.set("startTime", om.valueToTree(this.getStartTime()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-applicationautoscaling.ScalingSchedule"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ScalingSchedule.Jsii$Proxy that = (ScalingSchedule.Jsii$Proxy) o;

            if (!schedule.equals(that.schedule)) return false;
            if (this.endTime != null ? !this.endTime.equals(that.endTime) : that.endTime != null) return false;
            if (this.maxCapacity != null ? !this.maxCapacity.equals(that.maxCapacity) : that.maxCapacity != null) return false;
            if (this.minCapacity != null ? !this.minCapacity.equals(that.minCapacity) : that.minCapacity != null) return false;
            return this.startTime != null ? this.startTime.equals(that.startTime) : that.startTime == null;
        }

        @Override
        public int hashCode() {
            int result = this.schedule.hashCode();
            result = 31 * result + (this.endTime != null ? this.endTime.hashCode() : 0);
            result = 31 * result + (this.maxCapacity != null ? this.maxCapacity.hashCode() : 0);
            result = 31 * result + (this.minCapacity != null ? this.minCapacity.hashCode() : 0);
            result = 31 * result + (this.startTime != null ? this.startTime.hashCode() : 0);
            return result;
        }
    }
}

==> applicationautoscaling-1.93.0-sources.jar: software/amazon/awscdk/services/applicationautoscaling/ScalingSchedule.java <==
package software.amazon.awscdk.services.applicationautoscaling;

/**
 * A scheduled scaling action.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:25.777Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.applicationautoscaling.$Module.class, fqn = "@aws-cdk/aws-applicationautoscaling.ScalingSchedule")
@software.amazon.jsii.Jsii.Proxy(ScalingSchedule.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ScalingSchedule extends software.amazon.jsii.JsiiSerializable {

    /**
     * When to perform this action.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.Schedule getSchedule();

    /**
     * When this scheduled action expires.
     * <p>
     * Default: The rule never expires.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.time.Instant getEndTime() {
        return null;
    }

    /**
     * The new maximum capacity.
     * <p>
     * During the scheduled time, the current capacity is above the maximum
     * capacity, Application Auto Scaling scales in to the maximum capacity.
     * <p>
     * At least one of maxCapacity and minCapacity must be supplied.
     * <p>
     * Default: No new maximum capacity
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMaxCapacity() {
        return null;
    }

    /**
     * The new minimum capacity.
     * <p>
     * During the scheduled time, if the current capacity is below the minimum
     * capacity, Application Auto Scaling scales out to the minimum capacity.
     * <p>
     * At least one of maxCapacity and minCapacity must be supplied.
     * <p>
     * Default: No new minimum capacity
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getMinCapacity() {
        return null;
    }

    /**
     * When this scheduled action becomes active.
     * <p>
     * Default: The rule is activate immediately
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.time.Instant getStartTime() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ScalingSchedule> {
        private software.amazon.awscdk.services.applicationautoscaling.Schedule schedule;
        private java.time.Instant endTime;
        private java.lang.Number maxCapacity;
        private java.lang.Number minCapacity;
        private java.time.Instant startTime;

        /**
         * Sets the value of {@link ScalingSchedule#getSchedule}
         * @param schedule When to perform this action. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder schedule(software.amazon.awscdk.services.applicationautoscaling.Schedule schedule) {
            this.schedule = schedule;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getEndTime}
         * @param endTime When this scheduled action expires.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder endTime(java.time.Instant endTime) {
            this.endTime = endTime;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getMaxCapacity}
         * @param maxCapacity The new maximum capacity.
         *                    During the scheduled time, the current capacity is above the maximum
         *                    capacity, Application Auto Scaling scales in to the maximum capacity.
         *                    <p>
         *                    At least one of maxCapacity and minCapacity must be supplied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxCapacity(java.lang.Number maxCapacity) {
            this.maxCapacity = maxCapacity;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getMinCapacity}
         * @param minCapacity The new minimum capacity.
         *                    During the scheduled time, if the current capacity is below the minimum
         *                    capacity, Application Auto Scaling scales out to the minimum capacity.
         *                    <p>
         *                    At least one of maxCapacity and minCapacity must be supplied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minCapacity(java.lang.Number minCapacity) {
            this.minCapacity = minCapacity;
            return this;
        }

        /**
         * Sets the value of {@link ScalingSchedule#getStartTime}
         * @param startTime When this scheduled action becomes active.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder startTime(java.time.Instant startTime) {
            this.startTime = startTime;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ScalingSchedule}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ScalingSchedule build() {
            return new Jsii$Proxy(schedule, endTime, maxCapacity, minCapacity, startTime);
        }
    }

    /**
     * An implementation for {@link ScalingSchedule}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ScalingSchedule {
        private final software.amazon.awscdk.services.applicationautoscaling.Schedule schedule;
        private final java.time.Instant endTime;
        private final java.lang.Number maxCapacity;
        private final java.lang.Number minCapacity;
        private final java.time.Instant startTime;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.schedule = software.amazon.jsii.Kernel.get(this, "schedule", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.applicationautoscaling.Schedule.class));
            this.endTime = software.amazon.jsii.Kernel.get(this, "endTime", software.amazon.jsii.NativeType.forClass(java.time.Instant.class));
            this.maxCapacity = software.amazon.jsii.Kernel.get(this, "maxCapacity", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.minCapacity = software.amazon.jsii.Kernel.get(this, "minCapacity", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.startTime = software.amazon.jsii.Kernel.get(this, "startTime", software.amazon.jsii.NativeType.forClass(java.time.Instant.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.applicationautoscaling.Schedule schedule, final java.time.Instant endTime, final java.lang.Number maxCapacity, final java.lang.Number minCapacity, final java.time.Instant startTime) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.schedule = java.util.Objects.requireNonNull(schedule, "schedule is required");
            this.endTime = endTime;
            this.maxCapacity = maxCapacity;
            this.minCapacity = minCapacity;
            this.startTime = startTime;
        }

        @Override
        public final software.amazon.awscdk.services.applicationautoscaling.Schedule getSchedule() {
            return this.schedule;
        }

        @Override
        public final java.time.Instant getEndTime() {
            return this.endTime;
        }

        @Override
        public final java.lang.Number getMaxCapacity() {
            return this.maxCapacity;
        }

        @Override
        public final java.lang.Number getMinCapacity() {
            return this.minCapacity;
        }

        @Override
        public final java.time.Instant getStartTime() {
            return this.startTime;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("schedule", om.valueToTree(this.getSchedule()));
            if (this.getEndTime() != null) {
                data.set("endTime", om.valueToTree(this.getEndTime()));
            }
            if (this.getMaxCapacity() != null) {
                data.set("maxCapacity", om.valueToTree(this.getMaxCapacity()));
            }
            if (this.getMinCapacity() != null) {
                data.set("minCapacity", om.valueToTree(this.getMinCapacity()));
            }
            if (this.getStartTime() != null) {
                data.set("startTime", om.valueToTree(this.getStartTime()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-applicationautoscaling.ScalingSchedule"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ScalingSchedule.Jsii$Proxy that = (ScalingSchedule.Jsii$Proxy) o;

            if (!schedule.equals(that.schedule)) return false;
            if (this.endTime != null ? !this.endTime.equals(that.endTime) : that.endTime != null) return false;
            if (this.maxCapacity != null ? !this.maxCapacity.equals(that.maxCapacity) : that.maxCapacity != null) return false;
            if (this.minCapacity != null ? !this.minCapacity.equals(that.minCapacity) : that.minCapacity != null) return false;
            return this.startTime != null ? this.startTime.equals(that.startTime) : that.startTime == null;
        }

        @Override
        public final int hashCode() {
            int result = this.schedule.hashCode();
            result = 31 * result + (this.endTime != null ? this.endTime.hashCode() : 0);
            result = 31 * result + (this.maxCapacity != null ? this.maxCapacity.hashCode() : 0);
            result = 31 * result + (this.minCapacity != null ? this.minCapacity.hashCode() : 0);
            result = 31 * result + (this.startTime != null ? this.startTime.hashCode() : 0);
            return result;
        }
    }
}
